Crate fr_rust

Crate fr_rust 

Modules

crypto
db
ddos
email
jwt
linkv
macros
otp
prelude
redis
res
server
types
ws

Macros

http_assert_auth
Evaluates a boolean condition. If false, short-circuits the execution path and returns an HTTP 401 Unauthorized error with a custom message.
http_error
Unwraps a Result. If it’s an Err, automatically returns an HTTP 400 Bad Request response immediately, using fr-rust’s built-in http_bad helper.
http_try_500
Unwraps a Result. If it’s an Err, automatically converts it into an Actix-Web Internal Server Error (500) with a custom string message.
http_unwrap_or_404
Unwraps an Option. If it is None, returns an HTTP 404 Not Found response immediately.

Attribute Macros

main
Marks async main function as the Actix Web system entry-point.