Module prelude

Module prelude 

Re-exports

pub use crate::crypto;
pub use crate::crypto::CryptoService;
pub use crate::crypto::CryptoError;
pub use crate::db;
pub use crate::db::DbPool;
pub use crate::db::DbError;
pub use crate::ddos;
pub use crate::ddos::DdosConfig;
pub use crate::ddos::DdosShield;
pub use crate::email;
pub use crate::email::EmailConfig;
pub use crate::email::EmailData;
pub use crate::email::EmailService;
pub use crate::jwt;
pub use crate::jwt::JwtService;
pub use crate::linkv;
pub use crate::linkv::LinkV;
pub use crate::linkv::LinkVConfig;
pub use crate::otp;
pub use crate::otp::OtpConfig;
pub use crate::otp::OtpService;
pub use crate::redis;
pub use crate::redis::RedisManager;
pub use crate::redis::RedisManagerError;
pub use crate::server;
pub use crate::server::env;
pub use crate::server::env_or_default;
pub use crate::server::load_env;
pub use crate::types;
pub use crate::types::Main;
pub use crate::types::Http;
pub use crate::types::ResError;
pub use crate::ws;
pub use crate::ws::UserMsg;
pub use crate::ws::WsConfig;
pub use crate::ws::WsManager;
pub use crate::ws::MsgBatcher;
pub use crate::res;
pub use crate::res::http_ok_static;
pub use crate::res::http_ok_stream;
pub use crate::res::http_no_content;
pub use crate::res::http_created;
pub use crate::res::http_accepted;
pub use crate::res::http_partial_content;
pub use crate::res::http_bad_static;
pub use crate::res::http_unauthorized;
pub use crate::res::http_forbidden;
pub use crate::res::http_not_found;
pub use crate::res::http_method_not_allowed;
pub use crate::res::http_unsupported_media;
pub use crate::res::http_too_many_requests;
pub use crate::res::http_service_unavailable;
pub use crate::res::http_server_error;
pub use crate::res::send_file_fast;
pub use crate::res::stream_file_chunked;
pub use crate::res::send_file_range;
pub use crate::res::http_brotli;
pub use crate::res::http_lz4;
pub use crate::res::parse_multipart_stream;
pub use crate::res::parse_json_fast;
pub use crate::res::parse_range;
pub use crate::res::upload_with_progress;
pub use crate::res::upload_streaming;

Macros

delete
err
get
patch
post
put
resource
route
routes
run
scope

Structs

Config
Enables parts of app configuration to be declared separately from the app itself. Helpful for modularizing large applications.

Attribute Macros

web_main
Marks async main function as the Actix Web system entry-point.